#!/bin/bash

# For a given date, print the MODIS granule times when Terra or Aqua are within a defined lat/lon box

# Check arguments
if [ $# -ne 7 ]; then
  echo "Usage: overpass.bash name year jday lat1 lon1 lat2 lon2"
  echo "where"
  echo "name is satellite name (TERRA or AQUA)"
  echo "year is year (1999-)"
  echo "jday is day of year (1-366)"
  echo "lat1 is latitude of lower left corner of box (-90 to 90)"
  echo "lon1 is longitude of lower left corner of box (-180 to 180)"
  echo "lat2 is latitude of upper right corner of box (-90 to 90)"
  echo "lon2 is longitude of upper right corner of box (-180 to 180)"
  exit 1
fi

# Get arguments
name=$1
year=$2
jday=$3
lat1=$4
lon1=$5
lat2=$6
lon2=$7

# Update the orbital elements
curl -s -o TLINSET ftp://rtprods.ssec.wisc.edu/pub/nav/twoline.txt

# Call overpass.exe to get the granule times
date=$(date -d "$year/01/01 + $jday days - 1 days" +%y%m%d)
overpass.exe $date $name $lat1 $lon1 $lat2 $lon2 | uniq

exit 0
